package mvilla.posicionamientowifi;

import android.app.Activity;
import android.content.Intent;
import android.content.IntentFilter;
import android.os.Bundle;
import android.os.Environment;
import android.support.design.widget.FloatingActionButton;
import android.support.design.widget.Snackbar;
import android.support.v7.app.AppCompatActivity;
import android.support.v7.widget.Toolbar;
import android.view.View;
import android.view.Menu;
import android.view.MenuItem;
import android.widget.Button;
import android.widget.TextView;
import android.widget.Toast;

import java.util.Vector;

import mvilla.posicionamientowifi.Actividades.CAprendizaje;
import mvilla.posicionamientowifi.Actividades.CListaMapas;
import mvilla.posicionamientowifi.Actividades.CListaWifis;
import mvilla.posicionamientowifi.Actividades.CPosicionamiento;
import mvilla.posicionamientowifi.Definiciones.CDatoMapa;
import mvilla.posicionamientowifi.Definiciones.CInfoPosicionWifi;
import mvilla.posicionamientowifi.XMLParser.CMgrXML;

public class CMainActivity extends Activity
{
    private static final int CODIGO_ACTIVIDAD_LISTA_MAPAS = 1;

    public static  Vector<CDatoMapa> m_vMapas = new Vector<CDatoMapa>();

    private int m_posMapaEscogido = -1;

    private Button m_cmdAprendizaje;
    private Button m_cmdLimpiarDatos;
    private Button m_cmdPosicionamiento;
    private Button m_cmdEscogerMapa;
    private TextView m_nombreMapaEscogido;

    @Override
    protected void onCreate(Bundle savedInstanceState)
    {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_main);

        m_cmdAprendizaje = (Button)findViewById(R.id.cmdAprendizaje);
        m_cmdAprendizaje.setOnClickListener(new View.OnClickListener() {
            public void onClick(View view) {
                OnButtonAprendizaje();
            }
        });

        m_cmdLimpiarDatos = (Button)findViewById(R.id.cmdLimpiarDatos);
        m_cmdLimpiarDatos.setOnClickListener(new View.OnClickListener()
        {
            public void onClick(View view)
            {
                OnButtonLimpiarDatos();
            }
        });

        m_cmdPosicionamiento = (Button)findViewById(R.id.cmdPosicionamiento);
        m_cmdPosicionamiento.setOnClickListener(new View.OnClickListener()
        {
            public void onClick(View view)
            {
                OnButtonPoscionamiento();
            }
        });

        m_cmdEscogerMapa = (Button)findViewById(R.id.cmdSeleccionarMapa);
        m_cmdEscogerMapa.setOnClickListener(new View.OnClickListener()
        {
            public void onClick(View view)
            {
                OnButtonSeleccionarMapa();
            }
        });

        m_nombreMapaEscogido = (TextView)findViewById(R.id.txtNombreMapaEscogido);



        if (!Environment.getExternalStorageState().equals(Environment.MEDIA_MOUNTED))
        {
            Toast.makeText(this, "No tiene memoria externa", Toast.LENGTH_SHORT).show();
            finish();

        }

        CMgrXML mgr = new CMgrXML(this);
        m_vMapas = mgr.GetDatosMapas();

        if (m_vMapas.size() == 0)
        {
            Toast.makeText(this, "No existen mapas. Por favor añada un mapa a la carpeta: </storage/sdcard0/Android/data/mvilla.posicionamientowifi/files/xml/PosicionamientoWifi/MapasPosicionamiento.xml> ", Toast.LENGTH_SHORT).show();
            finish();
        }

        //Hasta que no tengamos el mapa escogido no podemos editar nada del mapa
        HabilitarDeshabilitarBotonesEdicion(false);
        m_nombreMapaEscogido.setText("No se ha escogido ningún mapa");
    }

    private void HabilitarDeshabilitarBotonesEdicion (boolean activar)
    {
        m_cmdAprendizaje.setEnabled(activar);
        m_cmdLimpiarDatos.setEnabled(activar);
        m_cmdPosicionamiento.setEnabled(activar);
    }

    private void OnButtonLimpiarDatos()
    {
        CADODatosWifis conBD = new CADODatosWifis(getBaseContext());
        if (conBD.ClearDatosMapa(m_vMapas.elementAt(m_posMapaEscogido).Nombre()))
            Toast.makeText(this, "Limpieza de datos del mapa <" + m_vMapas.elementAt(m_posMapaEscogido).Nombre() + "> terminada", Toast.LENGTH_SHORT ).show();
        else
            Toast.makeText(this, "Error al limpiar los datos del mapa <" + m_vMapas.elementAt(m_posMapaEscogido).Nombre() + "> terminada", Toast.LENGTH_SHORT ).show();
    }

    protected void onActivityResult (int requestCode, int resultCode, Intent data)
    {
        if (requestCode == CODIGO_ACTIVIDAD_LISTA_MAPAS && resultCode == RESULT_OK)
        {
            m_posMapaEscogido = data.getExtras().getInt(CDatosComunes.POSICION_MAPA_ESCOGIDO);

            if (m_posMapaEscogido != -1)
            {
                m_nombreMapaEscogido.setText("Mapa Escogido: " + m_vMapas.elementAt(m_posMapaEscogido).Nombre());
                HabilitarDeshabilitarBotonesEdicion(true);
            }
            else
            {
                m_nombreMapaEscogido.setText("Mapa Escogido: Ninguno");
                HabilitarDeshabilitarBotonesEdicion(false);
            }
        }
    }

    private void OnButtonAprendizaje ()
    {
        Intent i = new Intent(this, CAprendizaje.class);
        i.putExtra(CDatosComunes.POSICION_MAPA_ESCOGIDO, m_posMapaEscogido);
        startActivity(i);
    }

    private void OnButtonPoscionamiento()
    {
        Intent i = new Intent(this, CPosicionamiento.class);
        i.putExtra(CDatosComunes.POSICION_MAPA_ESCOGIDO, m_posMapaEscogido);
        startActivity(i);
    }

    private void OnButtonSeleccionarMapa()
    {
        Intent listaMapas = new Intent(this, CListaMapas.class);
        startActivityForResult(listaMapas, CODIGO_ACTIVIDAD_LISTA_MAPAS);
    }



}
