package mvilla.posicionamientowifi.Vistas;

import android.content.Context;
import android.graphics.Canvas;
import android.graphics.Color;
import android.graphics.Paint;
import android.graphics.Path;
import android.graphics.drawable.ShapeDrawable;
import android.graphics.drawable.shapes.PathShape;
import android.hardware.SensorEventListener;
import android.util.AttributeSet;
import android.view.Display;
import android.view.MotionEvent;
import android.view.View;
import android.view.WindowManager;
import android.widget.Button;
import android.widget.LinearLayout;
import android.widget.Toast;

import java.util.Vector;

import mvilla.posicionamientowifi.CMgrWifi;
import mvilla.posicionamientowifi.Definiciones.CDatoDepartamento;
import mvilla.posicionamientowifi.Definiciones.CDatoMapa;
import mvilla.posicionamientowifi.Definiciones.CInfoPosicionWifi;

/**
 * Created by Miguel on 27/10/2015.
 */
public class CVistaMapa extends View
{
    CDatoMapa   m_datosMapa;
    Vector<CVistaDepartamento> m_vVistaDepartamento;
    boolean     m_bDibujadoMapa;
    int         m_departamentoSeleccionado;

    float       m_posXPulsado;
    float       m_posYPulsado;

    float       m_anchoMapa = -1;
    float       m_altoMapa = -1;
    int         m_xMapa = 0;
    int         m_yMapa = 0;

    double      m_factorDivision = 0;

    boolean     m_bEnableSelection = false;

    Canvas      m_canvas;


     public CVistaMapa(Context context, AttributeSet attrs)
     {
         super(context, attrs);

         m_vVistaDepartamento = new Vector<CVistaDepartamento>();

         m_bDibujadoMapa = false;

         m_departamentoSeleccionado = -1;

         m_posXPulsado = -1;

         m_posYPulsado = -1;
     }

     public void SetDatosMapa (CDatoMapa datos, boolean enableSelection)
     {
        m_datosMapa = datos;
        m_bDibujadoMapa = false;
        m_bEnableSelection = enableSelection;

        m_vVistaDepartamento.clear();

        for (int i = 0; i < m_datosMapa.GetDatosDepartamentos().size(); i++)
        {
            CVistaDepartamento dato = new CVistaDepartamento(this, m_datosMapa.GetDatosDepartamentos().elementAt(i));
            m_vVistaDepartamento.add(dato);
        }
     }

     public void DibujarMapaCompleto ()
     {
         DibujarMapa(m_canvas);
     }

    protected void onDraw (Canvas canvas)
    {
        super.onDraw(canvas);

        m_canvas = canvas;

        if (m_vVistaDepartamento == null)
            return;

        if (!m_bDibujadoMapa)
        {
            CalcularFactorAjustePantalla();

            m_bDibujadoMapa = true;
        }

        DibujarMapa(canvas);

    }

     private void DibujarMapa (Canvas canvas)
     {
         Paint p = new Paint();
         p.setStrokeWidth(9);
         p.setColor(Color.BLACK);
         p.setStyle(Paint.Style.STROKE);

        for (int i = 0; i < m_vVistaDepartamento.size(); i++)
        {
            m_vVistaDepartamento.elementAt(i).DibujarDepartamento(canvas);
        }

         canvas.drawRect(m_xMapa, m_yMapa, m_anchoMapa + m_xMapa, m_altoMapa + m_yMapa, p);
     }

     private void CalcularFactorAjustePantalla ()
     {
        //Vemos si existe un valor inicial de X mayor que cero para ajustarlo
         int anchoPantalla = this.getWidth();
         int altoPantalla = this.getHeight();

        //Para poner la posicion Y = 0 al final de la pantalla y no arriba
         for (int i = 0; i < m_vVistaDepartamento.size(); i++)
         {
             m_vVistaDepartamento.elementAt(i).PosY(altoPantalla - (m_vVistaDepartamento.elementAt(i).PosY() + m_vVistaDepartamento.elementAt(i).Alto()));
         }

        int restarX = anchoPantalla;
        int restarY = altoPantalla;
        for (int i = 0; i < m_vVistaDepartamento.size(); i++)
        {
            if (m_vVistaDepartamento.elementAt(i).PosX() < restarX)
                restarX = m_vVistaDepartamento.elementAt(i).PosX();

            if (m_vVistaDepartamento.elementAt(i).PosY() < restarY)
                restarY = m_vVistaDepartamento.elementAt(i).PosY();
        }

        //Restamos esos valores a todos los miembros
         for (int i = 0; i < m_vVistaDepartamento.size(); i++)
         {
             m_vVistaDepartamento.elementAt(i).PosX(m_vVistaDepartamento.elementAt(i).PosX() - restarX);
             m_vVistaDepartamento.elementAt(i).PosY(m_vVistaDepartamento.elementAt(i).PosY() - restarY);
         }

         int maxAlto = 0;
         int maxAncho = 0;
         for (int i = 0; i < m_vVistaDepartamento.size(); i++)
         {
             if (m_vVistaDepartamento.elementAt(i).PosX() + m_vVistaDepartamento.elementAt(i).Ancho() > maxAncho)
                maxAncho = m_vVistaDepartamento.elementAt(i).PosX() + m_vVistaDepartamento.elementAt(i).Ancho();

             if (m_vVistaDepartamento.elementAt(i).PosY() + m_vVistaDepartamento.elementAt(i).Alto() > maxAlto)
                 maxAlto = m_vVistaDepartamento.elementAt(i).PosY() + m_vVistaDepartamento.elementAt(i).Alto();
         }

         //Calculamos el factor
         double factorAlto = (double)altoPantalla / (double)maxAlto;
         double factorAncho = (double)anchoPantalla / (double)maxAncho;

         if (factorAlto < factorAncho)
             m_factorDivision = factorAlto;
         else
             m_factorDivision = factorAncho;

         for (int i = 0; i < m_vVistaDepartamento.size(); i++)
         {
             m_vVistaDepartamento.elementAt(i).PosX((int) (m_vVistaDepartamento.elementAt(i).PosX() * m_factorDivision));
             m_vVistaDepartamento.elementAt(i).PosY((int) (m_vVistaDepartamento.elementAt(i).PosY() * m_factorDivision));
             m_vVistaDepartamento.elementAt(i).Alto((int) (m_vVistaDepartamento.elementAt(i).Alto() * m_factorDivision));
             m_vVistaDepartamento.elementAt(i).Ancho((int) (m_vVistaDepartamento.elementAt(i).Ancho() * m_factorDivision));

             if (m_vVistaDepartamento.elementAt(i).PosX() + m_vVistaDepartamento.elementAt(i).Ancho() > m_anchoMapa)
                m_anchoMapa = m_vVistaDepartamento.elementAt(i).PosX() + m_vVistaDepartamento.elementAt(i).Ancho();

             if (m_vVistaDepartamento.elementAt(i).PosY() + m_vVistaDepartamento.elementAt(i).Alto() > m_altoMapa)
                 m_altoMapa = m_vVistaDepartamento.elementAt(i).PosY() + m_vVistaDepartamento.elementAt(i).Alto();
         }

         if (m_anchoMapa < anchoPantalla)
         {
             m_xMapa = (int)(anchoPantalla - m_anchoMapa) / 2;

             for (int i = 0; i < m_vVistaDepartamento.size(); i++)
             {
                 m_vVistaDepartamento.elementAt(i).PosX(m_vVistaDepartamento.elementAt(i).PosX() + (int)m_xMapa);
             }
         }

         if (m_altoMapa < altoPantalla)
         {
             m_yMapa = (int)(altoPantalla - m_altoMapa) / 2;

             for (int i = 0; i < m_vVistaDepartamento.size(); i++)
             {
                 m_vVistaDepartamento.elementAt(i).PosY(m_vVistaDepartamento.elementAt(i).PosY() + (int)m_yMapa);
             }
         }
     }

    public boolean onTouchEvent (MotionEvent event)
    {
        super.onTouchEvent(event);

        if (!m_bEnableSelection)
            return true;

        m_posXPulsado = event.getX();
        m_posYPulsado = event.getY();

        m_departamentoSeleccionado = -1;
        for (int i = 0; i < m_vVistaDepartamento.size(); i++)
        {
            if (m_vVistaDepartamento.elementAt(i).PertenceADepartamento (m_posXPulsado, m_posYPulsado))
            {
                m_vVistaDepartamento.elementAt(i).Seleccionado(true);
                m_departamentoSeleccionado = i;
            }
            else
                m_vVistaDepartamento.elementAt(i).Seleccionado(false);
        }

        m_posXPulsado = (float)(m_posXPulsado / m_factorDivision);
        m_posYPulsado = (float)(m_posYPulsado / m_factorDivision);

        return true;
    }

    public CInfoPosicionWifi GetPosicionSeleccionada ()
    {
        if (m_departamentoSeleccionado != -1)
        {
            CInfoPosicionWifi datoPosicion = new CInfoPosicionWifi();
            datoPosicion.m_posY = m_posYPulsado;
            datoPosicion.m_posX = m_posXPulsado;
            datoPosicion.m_nombreDepartamento = m_vVistaDepartamento.elementAt(m_departamentoSeleccionado).Nombre();
            return (datoPosicion);
        }
        else
            return null;
    }

    public void SetPosicion (float posX, float posY)
    {
        m_posXPulsado = (float)(posX * m_factorDivision);
        m_posYPulsado = (float)(posY * m_factorDivision);

        m_departamentoSeleccionado = -1;
        for (int i = 0; i < m_vVistaDepartamento.size(); i++)
        {
            if (m_vVistaDepartamento.elementAt(i).PertenceADepartamento (m_posXPulsado, m_posYPulsado))
            {
                m_vVistaDepartamento.elementAt(i).Seleccionado(true);
                m_departamentoSeleccionado = i;
            }
            else
                m_vVistaDepartamento.elementAt(i).Seleccionado(false);
        }

        DibujarMapa(m_canvas);
        postInvalidate();

    }
}
